==> haskell-xml-1.3.14-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml
version: 1.3.14
id: xml-1.3.14-I3FZ7oToQdkKSAIpRAmioK
key: xml-1.3.14-I3FZ7oToQdkKSAIpRAmioK
license: BSD3
copyright: (c) 2007-2008 Galois Inc.
maintainer: diatchki@galois.com
homepage: http://code.galois.com
synopsis: A simple XML library.
description:
    A simple XML library.
category: Text, XML
author: Galois Inc.
exposed: True
indefinite: False
exposed-modules:
    Text.XML.Light Text.XML.Light.Cursor Text.XML.Light.Input
    Text.XML.Light.Lexer Text.XML.Light.Output Text.XML.Light.Proc
    Text.XML.Light.Types
abi: c962cf1fce06763b32f790c959d051a1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xml-1.3.14
library-dirs: /usr/lib/ghc-8.2.2/site-local/xml-1.3.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/xml-1.3.14
hs-libraries: HSxml-1.3.14-I3FZ7oToQdkKSAIpRAmioK
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
haddock-interfaces: /usr/share/doc/haskell-xml/html/xml.haddock
haddock-html: /usr/share/doc/haskell-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-1.3.14-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml
version: 1.3.14
id: xml-1.3.14-Iiopw2ucwBuIKdlkbvc4Gm
key: xml-1.3.14-Iiopw2ucwBuIKdlkbvc4Gm
license: BSD-3-Clause
copyright: (c) 2007-2008 Galois Inc.
maintainer: diatchki@galois.com
author: Galois Inc.
homepage: http://code.galois.com
synopsis: A simple XML library.
description:
    A simple XML library.
category: Text, XML
abi: 6f727b0a8cd9ade0e8e4b598ef2ae80c
exposed: True
exposed-modules:
    Text.XML.Light Text.XML.Light.Cursor Text.XML.Light.Input
    Text.XML.Light.Lexer Text.XML.Light.Output Text.XML.Light.Proc
    Text.XML.Light.Types
import-dirs: /usr/lib/ghc-8.4.2/site-local/xml-1.3.14
library-dirs: /usr/lib/ghc-8.4.2/site-local/xml-1.3.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/xml-1.3.14
hs-libraries: HSxml-1.3.14-Iiopw2ucwBuIKdlkbvc4Gm
depends:
    base-4.11.1.0 bytestring-0.10.8.2 text-1.2.3.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
haddock-interfaces: /usr/share/doc/haskell-xml/html/xml.haddock
haddock-html: /usr/share/doc/haskell-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
